print.samHL: Printing function for S3 class '"samHL"'

View source: R/samHL.R

print.samHLR Documentation

Printing function for S3 class "samHL"

Description

Print a summary of an object of class "samHL".

Usage

## S3 method for class 'samHL'
print(x, ...)

Arguments

x

An object with S3 class "samHL"

...

Additional arguments passed to methods; currently unused.

Details

The output includes the regularization path length and its degrees of freedom.

See Also

samHL


SAM documentation built on March 13, 2026, 9:08 a.m.