print.samQL: Printing function for S3 class '"samQL"'

View source: R/samQL.R

print.samQLR Documentation

Printing function for S3 class "samQL"

Description

Print a summary of an object of class "samQL".

Usage

## S3 method for class 'samQL'
print(x, ...)

Arguments

x

An object with S3 class "samQL"

...

Additional arguments passed to methods; currently unused.

Details

The output includes the regularization path length and its degrees of freedom.

See Also

samQL


SAM documentation built on March 13, 2026, 9:08 a.m.